// script.js
document.addEventListener('DOMContentLoaded', function () {
    const form = document.querySelector('.form');
    const rollnoInput = document.getElementById('rollno');
    const passwordInput = document.getElementById('password');
    const semesterSelect = document.getElementById('semester');
    const togglePasswordSpan = document.querySelector('.toggle-password');
    const loginButton = document.querySelector('.form-submit-btn');
  
    // Ensure the button is hidden initially
    loginButton.style.display = "none";
  
    // Toggle Password Visibility using Font Awesome icon
    togglePasswordSpan.addEventListener('click', function () {
      const icon = this.querySelector('i');
      if (passwordInput.type === 'password') {
        passwordInput.type = 'text';
        icon.classList.remove('fa-eye');
        icon.classList.add('fa-eye-slash');
      } else {
        passwordInput.type = 'password';
        icon.classList.remove('fa-eye-slash');
        icon.classList.add('fa-eye');
      }
    });
  
    // Function to check form validity and toggle the button's visibility
    function checkFormValidity() {
      const rollnoValue = rollnoInput.value.trim();
      const passwordValue = passwordInput.value.trim();
      const semesterValue = semesterSelect.value;
  
      const isRollValid = rollnoValue.length >= 6 && rollnoValue.length <= 10;
      const isPasswordValid = passwordValue.length >= 8 && passwordValue.length <= 20;
      const isSemesterSelected = semesterValue !== "";
  
      // Show the button only if all conditions are met
      if (isRollValid && isPasswordValid && isSemesterSelected) {
        loginButton.style.display = "block"; // You can also use "inline-block" if preferred.
      } else {
        loginButton.style.display = "none";
      }
    }
  
    // Add event listeners to validate inputs on the fly
    rollnoInput.addEventListener('input', checkFormValidity);
    passwordInput.addEventListener('input', checkFormValidity);
    semesterSelect.addEventListener('change', checkFormValidity);
  
    // Final validation on form submission
    form.addEventListener('submit', function (e) {
      let errors = [];
      const rollnoValue = rollnoInput.value.trim();
      const passwordValue = passwordInput.value.trim();
      const semesterValue = semesterSelect.value;
  
      if (rollnoValue.length < 6 || rollnoValue.length > 10) {
        errors.push('Roll No must be between 6 and 10 characters.');
      }
  
      if (passwordValue.length < 8 || passwordValue.length > 20) {
        errors.push('Password must be between 8 and 20 characters.');
      }
  
      if (semesterValue === '') {
        errors.push('Please select a semester.');
      }
  
      if (errors.length > 0) {
        e.preventDefault();
        alert(errors.join('\n'));
      }
    });
  });
  